@@ -1,10 +1,11 @@
-VERSION="0.1.5"
+VERSION='0.1.6'
 
 ENV_LIST = ['Knapsack-v0', 'Knapsack-v1', 'Knapsack-v2',
             'BinPacking-v0', 'BinPacking-v1', 'BinPacking-v2',
             'BinPacking-v3', 'BinPacking-v4', 'BinPacking-v5',
             'VMPacking-v0',
             'InvManagement-v0', 'InvManagement-v1',
+            'NetworkManagement-v0', 'NetworkManagement-v1',
             'PortfolioOpt-v0',
             'VehicleRouting-v0', 
             'Newsvendor-v0',
